BuildId

Struct BuildId 

pub struct BuildId {
    pub flavour: BuildIdFlavour,
    pub data: Vec<u8>,
}
Represents a build id, which could be either a GNU build ID, the build ID from Go, or a Sha256 hash of the code in the .text section.

Fields

flavour: BuildIdFlavourdata: Vec<u8>

Implementations

Source

impl BuildId

pub fn gnu_from_bytes(bytes: &[u8]) -> Result<Self, BuildIdError>

pub fn go_from_bytes(bytes: &[u8]) -> Result<Self, BuildIdError>

pub fn sha256_from_digest(digest: &Digest) -> Result<Self, BuildIdError>

pub fn id(&self) -> Result<ExecutableId>

Returns an identifier for the executable using the first 8 bytes of the build id.

pub fn short(&self) -> String

pub fn formatted(&self) -> String