pub struct ExecutableId(pub u64);Expand description
Compact identifier for executable files.
Compact identifier for executable files derived from the first 8 bytes of the build id. By using this smaller type for object files less memory is used and also comparison, and other operations are cheaper.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for ExecutableId
impl Clone for ExecutableId
Sourcefn clone(&self) -> ExecutableId
fn clone(&self) -> ExecutableId
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExecutableId
impl Debug for ExecutableId
Sourceimpl Display for ExecutableId
impl Display for ExecutableId
Sourceimpl From<ExecutableId> for u64
impl From<ExecutableId> for u64
Sourcefn from(executable_id: ExecutableId) -> Self
fn from(executable_id: ExecutableId) -> Self
Converts to this type from the input type.
Sourceimpl FromStr for ExecutableId
impl FromStr for ExecutableId
Sourceimpl Hash for ExecutableId
impl Hash for ExecutableId
Sourceimpl PartialEq for ExecutableId
impl PartialEq for ExecutableId
impl Copy for ExecutableId
impl Eq for ExecutableId
impl StructuralPartialEq for ExecutableId