ObjectFile

Struct ObjectFile 

pub struct ObjectFile { /* private fields */ }

Implementations

Source

impl ObjectFile

pub fn new(file: &File) -> Result<Self>

pub fn from_path(path: &Path) -> Result<Self>

pub fn id(&self) -> Result<ExecutableId>

Returns an identifier for the executable using the first 8 bytes of the build id.

pub fn build_id(&self) -> &BuildId

Returns the executable build ID.

pub fn read_build_id(object: &File<'static>) -> Result<BuildId>

Returns the executable build ID if present. If no GNU build ID and no Go build ID are found it returns the hash of the text section.

pub fn has_debug_info(&self) -> bool

Returns whether the object has debug symbols.

pub fn is_dynamic(&self) -> bool

pub fn runtime(&self) -> Runtime

pub fn is_go(&self) -> bool

pub fn go_stop_unwinding_frames(&self) -> Vec<StopUnwindingFrames>

pub fn elf_load_segments(&self) -> Result<Vec<ElfLoad>>

Retrieves the executable load segments. These are used to convert virtual addresses to offsets in an executable during unwinding and symbolization.